@@ -1,7 +1,7 @@
 {-# LANGUAGE UnboxedTuples #-}
 module Main where
 
-import GHC.Stack.CCS
+import GHC.InfoProv
 
 -- Unboxed data constructors don't have info tables so there is
 -- a special case to not generate distinct info tables for unboxed
